# How to setup

## First, type
#### Window
```
python install -r requirements.txt
```
#### Mac, Linux
```
python3 install -r requirements.txt
```

## Second, type
#### Window
```
python start.py install --user
```
#### Mac, Linux
```
python3 start.py install --user
```

Now, you can use this package to achieve your purpose.

---